<?php

/**
 * Fired during plugin activation
 *
 * @link       https://speechkit.io
 * @since      1.0.0
 *
 * @package    Speechkit
 * @subpackage Speechkit/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Speechkit
 * @subpackage Speechkit/includes
 * @author     Kostas Vaggelakos <kostas@speechkit.io>
 */
class Speechkit_Activator {

	/**
	 * The version of this plugin.
	 *
	 * @since    2.5.0
	 * @access   public
	 * @var      string    $version    The current version of this plugin.
	 */
	public static $version;

	public function __construct() {
		// 2.4.9 is for compatibility with versions prior 2.5.0
		self::$version = get_option( 'speechkit_version', '2.4.9' );
	}

	/**
	 * Upgrade database on plugin update.
	 *
	 * This is mostly for migration from <=2.4.9 to 2.5.0
	 *
	 * @return void
	 * @since    2.5.0
	 */
	public static function activate() {

		if ( version_compare( self::$version, '2.5.0', '<' ) ) {

			if ( get_option( 'sk_enabled' ) ) {
				$options = array(
					'speechkit_enable'            => get_option( 'sk_enabled' ),
					'speechkit_id'                => get_option( 'sk_news_site_id' ),
					'speechkit_api_key'           => get_option( 'sk_api_key' ),
					'speechkit_merge_excerpt'     => get_option( 'sk_combine_excerpt_with_body' ),
					'speechkit_select_post_types' => get_option( 'sk_post_types' ),
				);

				update_option( 'speechkit_settings', $options, true );

				delete_option( 'sk_enabled' );
				delete_option( 'sk_news_site_id' );
				delete_option( 'sk_api_key' );
				delete_option( 'sk_backend' );
				delete_option( 'sk_analytics_id' );
				delete_option( 'sk_analytics_key' );
				delete_option( 'sk_player_version' );
				delete_option( 'sk_execution_order' );
				delete_option( 'sk_processing_posts' );
				delete_option( 'sk_player' );
				delete_option( 'sk_post_types' );
				delete_option( 'sk_combine_excerpt_with_body' );
			}
		}

		update_option( 'speechkit_version', '2.6.6', true );
	}

}
