<?php


class SpeechkitAPI {

	function __construct( $version, $api_key, $backend, $news_site_id ) {
		$this->version      = $version;
		$this->api_key      = $api_key;
		$this->backend      = empty( $backend ) ? 'https://app.speechkit.io' : $backend;
		$this->news_site_id = $news_site_id;
	}

	private function generate_headers() {
		return array(
			'Authorization' => 'Token token=' . $this->api_key,
			'Content-Type'  => 'application/json',
			'User-Agent'    => 'SpeechKit WP Plugin v' . $this->version,
		);
	}

	private function generate_default_fetch_options() {
		return array(
			'headers'     => $this->generate_headers(),
			'blocking'    => true,
			'timeout'     => 60,
			'httpversion' => '1.1',
		);
	}

	private function generate_body_from_post( $post_id, $state = false ) {
		$options   = get_option( 'speechkit_settings' );
		$post      = get_post( $post_id );
		$post_meta = get_post_meta( $post_id, 'speechkit_info', true );
		// Parse out all data
		$external_id = $post_id;
		$title       = $post->post_title;

		// $body = wp_strip_all_tags( apply_filters( 'the_content', $post->post_content ) );
        $body_pre = $post->post_content;
        if ( preg_match_all('/\[SpeechKit-Start\](.*?)\[SpeechKit-Stop\]/s', $body_pre, $match, PREG_PATTERN_ORDER) > 0 ) {
            $body_pre = implode(' ', $match[1]);
        }
		$body = apply_filters( 'the_content', $body_pre );
        if( empty($body) ){
            $body = $body_pre;
        }
		// Merge the excerpt if the option is picked.
		if ( $options['speechkit_merge_excerpt'] == 1 ) {
			$body = $post->post_excerpt . '. ' . $body;
		}
		// $summary = wp_strip_all_tags(apply_filters('the_excerpt', $post->post_content ));
		$external_url = get_permalink( $post_id );
		$published_at = $post->post_date_gmt;
		$author       = get_the_author_meta( 'display_name', $post->post_author );
		$image_url    = get_the_post_thumbnail_url( $post_id, 'thumbnail' );

		//Get version in the repository
		if ( ! function_exists( 'plugins_api' ) ) {
			require_once( ABSPATH . 'wp-admin/includes/plugin-install.php' );
		}
		$args = array(
			'slug' => 'speechkit',
			'fields' => array(
				'version' => true,
			)
		);

		$call_api = plugins_api( 'plugin_information', $args );
		$latest_latest		= '';
		$publisher_version	= $this->version;
		if ( !is_wp_error( $call_api ) ) {
			if ( ! empty( $call_api->version ) ) {
				$latest_latest = $call_api->version;
			}

		}
		$body = array(
			'external_id'		=> $external_id,
			'title'        		=> $title,
			'body'         		=> $body,
			// 'summary' => $summary,
			'external_url' 		=> $external_url,
			'published_at' 		=> $published_at,
			'author'       		=> $author,
			'image_url'    		=> $image_url,
			'publisher_version'	=> $publisher_version,
			'latest_version'	=> $latest_latest,
		);

		if( $state && !empty( $state ) ){
			$body['state']		= $state;
		}

		//Callback url for processing
		$body['callback_url']	= get_site_url() . '/wp-admin/admin-post.php?action=speechkit_update';

		if ( $post_meta && $post_meta['media'] ) {
			$body['media_attributes'] = $post_meta['media'];
		} else {
			$body['media_attributes'] = array(
				array(
					'role' => 'body',
				),
			);
		}
		return json_encode( $body );
	}

	private function generate_base_url() {
		return $this->backend . '/api/v2/projects/' . $this->news_site_id . '/';
	}

	public function get_article( $post_id ) {
		$url = $this->generate_base_url() . 'podcasts/' . $post_id . '?cache=false';
		return wp_remote_get( $url, $this->generate_default_fetch_options() );
	}

	public function create_article( $post_id, $state = false ) {
		update_post_meta( $post_id, 'speechkit_req_create', $this->generate_body_from_post( $post_id, $state ) );
		return wp_remote_post(
			$this->generate_base_url() . 'podcasts', // $url
			array_merge(
				$this->generate_default_fetch_options(),
				array(
					'method' => 'POST',
					'body'   => $this->generate_body_from_post( $post_id, $state ),
				)
			)
		);
	}

	public function update_article( $post_id, $state = 'unprocessed' ) {
        update_post_meta( $post_id, 'speechkit_req_update', $this->generate_body_from_post( $post_id, $state ) );
		return wp_remote_post(
			$this->generate_base_url() . 'podcasts/' . $post_id, // $url
			array_merge(
				$this->generate_default_fetch_options(),
				array(
					'method' => 'PUT',
					'body'   => $this->generate_body_from_post( $post_id, $state ),
				)
			)
		);
	}

}
